summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2022-09-23 20:26:11 +0200
committerJohnny Willemsen <jwillemsen@remedy.nl>2022-09-23 20:26:11 +0200
commit2c45e323a5b597d17b1389abeb8be2fd25c74154 (patch)
tree1e0a06d8bf164e61db03c7068b88bef8022d8aa9
parent90cfc149fdf58636ba5474b8ee5a3e60d24d7d90 (diff)
downloadATCD-2c45e323a5b597d17b1389abeb8be2fd25c74154.tar.gz
Fixed documentation of ~ACE_DLList and use nullptr
* ACE/ace/Containers_T.h: * ACE/ace/Containers_T.inl:
-rw-r--r--ACE/ace/Containers_T.h10
-rw-r--r--ACE/ace/Containers_T.inl7
2 files changed, 5 insertions, 12 deletions
diff --git a/ACE/ace/Containers_T.inl b/ACE/ace/Containers_T.inl
index 9ef0b04df29..117ec4dcc65 100644
--- a/ACE/ace/Containers_T.inl
+++ b/ACE/ace/Containers_T.inl
@@ -156,9 +156,6 @@ ACE_Unbounded_Stack<T>::size () const
// ---
-
-// ---
-
template <class T, size_t ACE_SIZE> ACE_INLINE int
ACE_Fixed_Set<T, ACE_SIZE>::is_empty () const
{
@@ -245,10 +242,6 @@ ACE_Ordered_MultiSet_Iterator<T>::dump () const
#endif /* ACE_HAS_DUMP */
}
-
-
-// --
-
template <class T> ACE_INLINE int
ACE_Ordered_MultiSet<T>::is_empty () const
{
diff --git a/ACE/ace/Containers_T.h b/ACE/ace/Containers_T.h
index b4739ea6c34..d52a970921a 100644
--- a/ACE/ace/Containers_T.h
+++ b/ACE/ace/Containers_T.h
@@ -1084,9 +1084,9 @@ public:
*
* @param the_allocator Allocator to use for allocating ACE_DLList_Node
* objects that wrap T objects for inclusion in the
* list. If 0, ACE_Allocator::instance() is used.
*/
- ACE_DLList (ACE_Allocator *the_allocator = 0);
+ ACE_DLList (ACE_Allocator *the_allocator = nullptr);
/// Delegates to ACE_Double_Linked_List.
ACE_DLList (const ACE_DLList<T> &l);
@@ -1100,9 +1100,9 @@ public:
* @code
ACE_DLList<Item> list;
... // insert dynamically allocated Items...
- Item *p;
- while ((p = list.delete_head()) != 0)
- delete *p;
+ Item *p = nullptr;
+ while ((p = list.delete_head()) != nullptr)
+ delete p;
@endcode
*/
~ACE_DLList ();
@@ -1084,9 +1084,9 @@ public:
* @param the_allocator Allocator to use for allocating ACE_DLList_Node
* objects that wrap T objects for inclusion in the
- * list. If 0, ACE_Allocator::instance() is used.
+ * list. If nullptr, ACE_Allocator::instance() is used.
*/